@@ -1,3 +1,5 @@
+use std::ops::{Deref, DerefMut};
+
 use clap::Parser;
 
 use crate::common::CommonOptions;
@@ -29,3 +31,29 @@ pub struct Run {
     #[clap(takes_value = true, multiple_values = true)]
     pub args: Vec<String>,
 }
+
+impl Deref for Run {
+    type Target = CommonOptions;
+
+    fn deref(&self) -> &Self::Target {
+        &self.common
+    }
+}
+
+impl DerefMut for Run {
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.common
+    }
+}
+
+impl From<Run> for crate::Build {
+    fn from(run: Run) -> Self {
+        crate::Build {
+            common: run.common,
+            packages: run.packages.map(|p| vec![p]).unwrap_or_default(),
+            bin: run.bin,
+            example: run.example,
+            ..Default::default()
+        }
+    }
+}
